PYMONGOOSE_VERSION = "1.3"
PYMONGOOSE_VERSION_NAME = "Version 1.3"
PYMONGOOSE_VERSION_AUTHOR = "Juan Carlos Lara"

def pymongoose_version_print_full():
    print(f"{PYMONGOOSE_VERSION} - {PYMONGOOSE_VERSION_NAME}\nBy: {PYMONGOOSE_VERSION_AUTHOR}")